Documentation
¶
Overview ¶
M3:2048 Bloom filter
Useful for reducing a log entry into a single 256-byte hash
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Filter ¶
type Filter [256]byte
Bloom filter implementation based on the Yellow Paper/4.3.1:
M3:2048 is a specialised Bloom filter that sets three bits out of 2048, given an arbitrary byte sequence. It does this through taking the low-order 11 bits of each of the first three pairs of bytes in a Keccak-256 hash of the byte sequence.
Click to show internal directories.
Click to hide internal directories.